@@ -10,9 +10,11 @@ class User:
     """Represents an AMcards user."""
     def __init__(
         self,
+        id: int,
         first_name: str,
         last_name: str,
         credits: int,
+        email: str,
         date_joined: datetime,
         address_line_1: str,
         city: str,
@@ -24,9 +26,11 @@ class User:
         domestic_postage_countries: set,
         greeting_card_cost: int,
     ) -> None:
+        self._id = id
         self._first_name = first_name
         self._last_name = last_name
         self._credits = credits
+        self._email = email
         self._date_joined = date_joined
         self._address_line_1 = address_line_1
         self._city = city
@@ -40,6 +44,11 @@ class User:
 
     __repr__ = helpers.repr
 
+    @property
+    def id(self) -> int:
+        """User's unique identifier."""
+        return self._id
+
     @property
     def first_name(self) -> str:
         """User's first name."""
@@ -55,6 +64,11 @@ class User:
         """User's credit balance in `cents`."""
         return self._credits
 
+    @property
+    def mail(self) -> str:
+        """User's email address."""
+        return self._email
+
     @property
     def date_joined(self) -> datetime:
         """Date and time when user created their AMcards account."""
@@ -108,10 +122,15 @@ class User:
 
     @classmethod
     def _from_json(cls, json: dict):
+        user_id = json['resource_uri']
+        user_id = user_id[user_id.find('user/')+5:]
+        if not user_id[-1].isdigit(): user_id = user_id[:-1]
         return cls(
+            id=int(user_id),
             first_name=json['first_name'],
             last_name=json['last_name'],
             credits=json['credits'],
+            email=json['email'],
             date_joined=helpers.to_datetime(json['date_joined']),
             address_line_1=json['address_line_1'],
             city=json['city'],
@@ -124,28 +143,6 @@ class User:
             greeting_card_cost=json['product_pricing_info']['5x7greetingcard']
         )
 
-    def __str__(self) -> str:
-        formatted_credits = helpers.format_cents(price_in_cents=self.credits)
-        formatted_domestic_postage_cost = helpers.format_cents(price_in_cents=self.domestic_postage_cost)
-        formatted_international_postage_cost = helpers.format_cents(price_in_cents=self.international_postage_cost)
-        formatted_greeting_card_cost = helpers.format_cents(price_in_cents=self.greeting_card_cost)
-        formatted_domestic_postage_countries = ', '.join(self.domestic_postage_countries)
-        return (
-            f'First Name: {self.first_name}\n'
-            f'Last Name: {self.last_name}\n'
-            f'Credit Balance: {formatted_credits}\n'
-            f'Date Joined: {self.date_joined}\n'
-            f'Address Line 1: {self.address_line_1}\n'
-            f'City: {self.city}\n'
-            f'State: {self.state}\n'
-            f'Postal Code: {self.postal_code}\n'
-            f'Country: {self.country}\n'
-            f'Domestic Postage Cost: {formatted_domestic_postage_cost}\n'
-            f'International Postage Cost: {formatted_international_postage_cost}\n'
-            f'Domestic Postage Countries: {formatted_domestic_postage_countries}\n'
-            f'Greeting Card Cost: {formatted_greeting_card_cost}\n'
-        )
-
 class Gift:
     """Represents an AMcards gift."""
     def __init__(
@@ -628,27 +625,27 @@ class Contact:
 
     @property
     def birth_month(self) -> Optional[str]:
-        """Contact's birth month in the form ``"MM"``. ``None`` if contact doesnt' have a birth month."""
+        """Contact's birth month in the form ``"MM"``. ``None`` if contact doesn't have a birth month."""
         return self._birth_month
 
     @property
     def birth_day(self) -> Optional[str]:
-        """Contact's birth day in the form ``"DD"``. ``None`` if contact doesnt' have a birth day."""
+        """Contact's birth day in the form ``"DD"``. ``None`` if contact doesn't have a birth day."""
         return self._birth_day
 
     @property
     def anniversary_year(self) -> Optional[str]:
-        """Contact's anniversary year in the form ``"YYYY"``. ``None`` if contact doesnt' have an anniversary year."""
+        """Contact's anniversary year in the form ``"YYYY"``. ``None`` if contact doesn't have an anniversary year."""
         return self._anniversary_year
 
     @property
     def anniversary_month(self) -> Optional[str]:
-        """Contact's anniversary month in the form ``"MM"``. ``None`` if contact doesnt' have an anniversary month."""
+        """Contact's anniversary month in the form ``"MM"``. ``None`` if contact doesn't have an anniversary month."""
         return self._anniversary_month
 
     @property
     def anniversary_day(self) -> Optional[str]:
-        """Contact's anniversary day in the form ``"DD"``. ``None`` if contact doesnt' have an anniversary day."""
+        """Contact's anniversary day in the form ``"DD"``. ``None`` if contact doesn't have an anniversary day."""
         return self._anniversary_day
 
     @classmethod
